@@ -2,7 +2,7 @@
    nslcd.c - ldap local connection daemon
 
    Copyright (C) 2006 West Consulting
-   Copyright (C) 2006-2014 Arthur de Jong
+   Copyright (C) 2006-2015 Arthur de Jong
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -78,6 +78,10 @@
 #define WRITEBUFFER_MINSIZE 1024
 #define WRITEBUFFER_MAXSIZE 1 * 1024 * 1024
 
+/* adjust the oom killer score */
+#define OOM_SCORE_ADJ_FILE "/proc/self/oom_score_adj"
+#define OOM_SCORE_ADJ "-1000"
+
 /* flag to indicate if we are in debugging mode */
 static int nslcd_debugging = 0;
 
@@ -117,7 +121,7 @@ static void display_version(FILE *fp)
 {
   fprintf(fp, "%s\n", PACKAGE_STRING);
   fprintf(fp, "Written by Luke Howard and Arthur de Jong.\n\n");
-  fprintf(fp, "Copyright (C) 1997-2014 Luke Howard, Arthur de Jong and West Consulting\n"
+  fprintf(fp, "Copyright (C) 1997-2015 Luke Howard, Arthur de Jong and West Consulting\n"
               "This is free software; see the source for copying conditions.  There is NO\n"
               "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n");
 }
@@ -356,8 +360,8 @@ static void handleconnection(int sock, MYLDAP_SESSION *session)
   if (getpeercred(sock, &uid, &gid, &pid))
     log_log(LOG_DEBUG, "connection from unknown client: %s", strerror(errno));
   else
-    log_log(LOG_DEBUG, "connection from pid=%d uid=%d gid=%d",
-            (int)pid, (int)uid, (int)gid);
+    log_log(LOG_DEBUG, "connection from pid=%lu uid=%lu gid=%lu",
+            (unsigned long int)pid, (unsigned long int)uid, (unsigned long int)gid);
   /* create a stream object */
   if ((fp = tio_fdopen(sock, READ_TIMEOUT, WRITE_TIMEOUT,
                        READBUFFER_MINSIZE, READBUFFER_MAXSIZE,
@@ -477,7 +481,7 @@ static void create_pidfile(const char *filename)
               filename, strerror(errno));
       exit(EXIT_FAILURE);
     }
-    mysnprintf(buffer, sizeof(buffer), "%d\n", (int)getpid());
+    mysnprintf(buffer, sizeof(buffer), "%lu\n", (unsigned long int)getpid());
     if (write(fd, buffer, strlen(buffer)) != (int)strlen(buffer))
     {
       log_log(LOG_ERR, "error writing pid file (%s): %s",
@@ -608,7 +612,7 @@ static void disable_nss_ldap(void)
   /* clear any existing errors */
   dlerror();
   /* lookup the NSS version if possible */
-  version_info = (char **)dlsym(handle, "_nss_ldap_version");
+  version_info = (char **)dlsym(handle, "_nss_" MODULE_NAME "_version");
   error = dlerror();
   if ((version_info != NULL) && (error == NULL))
     log_log(LOG_DEBUG, "NSS_LDAP %s %s", version_info[0], version_info[1]);
@@ -617,7 +621,7 @@ static void disable_nss_ldap(void)
   /* clear any existing errors */
   dlerror();
   /* try to look up the flag */
-  enable_flag = (int *)dlsym(handle, "_nss_ldap_enablelookups");
+  enable_flag = (int *)dlsym(handle, "_nss_" MODULE_NAME "_enablelookups");
   error = dlerror();
   if ((enable_flag == NULL) || (error != NULL))
   {
@@ -640,6 +644,24 @@ static void disable_nss_ldap(void)
 #endif /* RTLD_NODELETE */
 }
 
+/* poke the OOM killer so nslcd will never get killed */
+static void adjust_oom_score(void)
+{
+  int oom_adj_fd;
+  if ((oom_adj_fd = open(OOM_SCORE_ADJ_FILE, O_WRONLY)) >= 0)
+  {
+    if (write(oom_adj_fd, OOM_SCORE_ADJ, strlen(OOM_SCORE_ADJ)) < 0)
+      log_log(LOG_WARNING, "writing oom score adjustment of %s failed: %s",
+        OOM_SCORE_ADJ, strerror(errno));
+    close(oom_adj_fd);
+  }
+  else
+  {
+    log_log(LOG_DEBUG, "could not open %s to adjust the OOM score: %s",
+      OOM_SCORE_ADJ_FILE, strerror(errno));
+  }
+}
+
 /* the main program... */
 int main(int argc, char *argv[])
 {
@@ -648,6 +670,17 @@ int main(int argc, char *argv[])
 #ifdef HAVE_PTHREAD_TIMEDJOIN_NP
   struct timespec ts;
 #endif /* HAVE_PTHREAD_TIMEDJOIN_NP */
+  /* block all these signals so our worker threads won't handle them */
+  sigemptyset(&signalmask);
+  sigaddset(&signalmask, SIGHUP);
+  sigaddset(&signalmask, SIGINT);
+  sigaddset(&signalmask, SIGQUIT);
+  sigaddset(&signalmask, SIGABRT);
+  sigaddset(&signalmask, SIGPIPE);
+  sigaddset(&signalmask, SIGTERM);
+  sigaddset(&signalmask, SIGUSR1);
+  sigaddset(&signalmask, SIGUSR2);
+  pthread_sigmask(SIG_BLOCK, &signalmask, &oldmask);
   /* close all file descriptors (except stdin/out/err) */
   daemonize_closefds();
   /* parse the command line */
@@ -729,6 +762,7 @@ int main(int argc, char *argv[])
     daemonize_ready(EXIT_FAILURE, "atexit() failed\n");
     exit(EXIT_FAILURE);
   }
+  adjust_oom_score();
   /* create socket */
   nslcd_serversocket = create_socket(NSLCD_SOCKET);
   /* start subprocess to do invalidating if reconnect_invalidate is set */
@@ -743,11 +777,11 @@ int main(int argc, char *argv[])
 #ifdef HAVE_INITGROUPS
     /* load supplementary groups */
     if (initgroups(nslcd_cfg->uidname, nslcd_cfg->gid) < 0)
-      log_log(LOG_WARNING, "cannot initgroups(\"%s\",%d) (ignored): %s",
-              nslcd_cfg->uidname, (int)nslcd_cfg->gid, strerror(errno));
+      log_log(LOG_WARNING, "cannot initgroups(\"%s\",%lu) (ignored): %s",
+              nslcd_cfg->uidname, (unsigned long int)nslcd_cfg->gid, strerror(errno));
     else
-      log_log(LOG_DEBUG, "initgroups(\"%s\",%d) done",
-              nslcd_cfg->uidname, (int)nslcd_cfg->gid);
+      log_log(LOG_DEBUG, "initgroups(\"%s\",%lu) done",
+              nslcd_cfg->uidname, (unsigned long int)nslcd_cfg->gid);
 #else /* not HAVE_INITGROUPS */
 #ifdef HAVE_SETGROUPS
     /* just drop all supplemental groups */
@@ -766,36 +800,25 @@ int main(int argc, char *argv[])
   {
     if (setgid(nslcd_cfg->gid) != 0)
     {
-      log_log(LOG_ERR, "cannot setgid(%d): %s",
-              (int)nslcd_cfg->gid, strerror(errno));
+      log_log(LOG_ERR, "cannot setgid(%lu): %s",
+              (unsigned long int)nslcd_cfg->gid, strerror(errno));
       daemonize_ready(EXIT_FAILURE, "cannot setgid()\n");
       exit(EXIT_FAILURE);
     }
-    log_log(LOG_DEBUG, "setgid(%d) done", (int)nslcd_cfg->gid);
+    log_log(LOG_DEBUG, "setgid(%lu) done", (unsigned long int)nslcd_cfg->gid);
   }
   /* change to nslcd uid */
   if (nslcd_cfg->uid != NOUID)
   {
     if (setuid(nslcd_cfg->uid) != 0)
     {
-      log_log(LOG_ERR, "cannot setuid(%d): %s",
-              (int)nslcd_cfg->uid, strerror(errno));
+      log_log(LOG_ERR, "cannot setuid(%lu): %s",
+              (unsigned long int)nslcd_cfg->uid, strerror(errno));
       daemonize_ready(EXIT_FAILURE, "cannot setuid()\n");
       exit(EXIT_FAILURE);
     }
-    log_log(LOG_DEBUG, "setuid(%d) done", (int)nslcd_cfg->uid);
+    log_log(LOG_DEBUG, "setuid(%lu) done", (unsigned long int)nslcd_cfg->uid);
   }
-  /* block all these signals so our worker threads won't handle them */
-  sigemptyset(&signalmask);
-  sigaddset(&signalmask, SIGHUP);
-  sigaddset(&signalmask, SIGINT);
-  sigaddset(&signalmask, SIGQUIT);
-  sigaddset(&signalmask, SIGABRT);
-  sigaddset(&signalmask, SIGPIPE);
-  sigaddset(&signalmask, SIGTERM);
-  sigaddset(&signalmask, SIGUSR1);
-  sigaddset(&signalmask, SIGUSR2);
-  pthread_sigmask(SIG_BLOCK, &signalmask, &oldmask);
   /* start worker threads */
   log_log(LOG_INFO, "accepting connections");
   nslcd_threads = (pthread_t *)malloc(nslcd_cfg->threads * sizeof(pthread_t));
